Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(765)

Unified Diff: chrome/browser/dom_ui/options/core_options_handler.h

Issue 3584019: dom-ui settings: Add setting for setting the minimum font size.... (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: '' Created 10 years, 2 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/dom_ui/options/core_options_handler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/dom_ui/options/core_options_handler.h
===================================================================
--- chrome/browser/dom_ui/options/core_options_handler.h (revision 62351)
+++ chrome/browser/dom_ui/options/core_options_handler.h (working copy)
@@ -46,6 +46,9 @@
const std::string& value_string,
const std::string& metric);
+ // Clears pref value for given |pref_name|.
+ void ClearPref(const std::string& pref_name, const std::string& metric);
+
// Stops observing given preference identified by |path|.
virtual void StopObservingPref(const std::string& path);
@@ -63,9 +66,9 @@
void HandleInitialize(const ListValue* args);
// Callback for the "fetchPrefs" message. This message accepts the list of
// preference names passed as |value| parameter (ListValue). It passes results
// dictionary of preference values by calling prefsFetched() JS method on the
// page.
void HandleFetchPrefs(const ListValue* args);
// Callback for the "observePrefs" message. This message initiates
@@ -73,8 +76,10 @@
void HandleObservePrefs(const ListValue* args);
// Callbacks for the "set<type>Pref" message. This message saves the new
- // preference value. The input value is an array of strings representing
- // name-value preference pair.
+ // preference value. |args| is an array of parameters as follows:
+ // item 0 - name of the preference.
+ // item 1 - the value of the preference in string form.
+ // item 2 - name of the metric identifier (optional).
void HandleSetBooleanPref(const ListValue* args);
void HandleSetIntegerPref(const ListValue* args);
void HandleSetStringPref(const ListValue* args);
@@ -82,8 +87,15 @@
void HandleSetPref(const ListValue* args, Value::ValueType type);
+ // Callback for the "clearPref" message. This message clears a preference
+ // value. |args| is an array of parameters as follows:
+ // item 0 - name of the preference.
+ // item 1 - name of the metric identifier (optional).
+ void HandleClearPref(const ListValue* args);
+
// Callback for the "coreOptionsUserMetricsAction" message. This records
- // an action that should be tracked if metrics recording is enabled.
+ // an action that should be tracked if metrics recording is enabled. |args|
+ // is an array that contains a single item, the name of the metric identifier.
void HandleUserMetricsAction(const ListValue* args);
void NotifyPrefChanged(const std::string* pref_name);
« no previous file with comments | « chrome/app/generated_resources.grd ('k') | chrome/browser/dom_ui/options/core_options_handler.cc » ('j') | no next file with comments »
@@ -63,9 +66,9 @@
void HandleInitialize(const ListValue* args);
// Callback for the "fetchPrefs" message. This message accepts the list of
- // preference names passed as |value| parameter (ListValue). It passes results
- // dictionary of preference values by calling prefsFetched() JS method on the
- // page.
+ // preference names passed as the |args| parameter (ListValue). It passes
+ // results dictionary of preference values by calling prefsFetched() JS method
+ // on the page.
void HandleFetchPrefs(const ListValue* args);
// Callback for the "observePrefs" message. This message initiates

Powered by Google App Engine
This is Rietveld 408576698